﻿using System;
using System.ComponentModel;
using System.Windows.Input;

namespace MvvmDemo
{
    public class MainViewModel : INotifyPropertyChanged
    {
        private Person _modelPerson;
        public Person ModelPerson
        {
            get { return _modelPerson; }
            set
            {
                _modelPerson = value;
                OnPropertyChanged("ModelPerson");
            }
        }

        private MyCommand _saveCommand;
        public MyCommand SaveCommand
        {
            get { return _saveCommand; }
            set
            {
                _saveCommand = value;
                OnPropertyChanged("SaveCommand");
            }
        }
        

        public MainViewModel()
        {
            LoadPerson();
            InitializeCommands();
        }

        private void LoadPerson()
        {
            ModelPerson = new Person()
            {
                FirstName = "Brian",
                LastName = "Lagunas",
                Age = 32
            };
        }

        private void InitializeCommands()
        {
            SaveCommand = new MyCommand(Save);
        }

        private void Save()
        {
            ModelPerson.LastUpdated = DateTime.Now;
        }

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;
        public void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }

        #endregion
    }

    public class MyCommand : ICommand
    {
        Action _action;

        public MyCommand(Action action)
        {
            _action = action;
        }

        #region ICommand Members

        public bool CanExecute(object parameter)
        {
            return true;
        }

        public event EventHandler CanExecuteChanged;

        public void Execute(object parameter)
        {
            _action.Invoke();
        }

        #endregion
    }
}
